summaryrefslogtreecommitdiff
path: root/nuttx/drivers/net/encx24j600.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/drivers/net/encx24j600.c')
-rw-r--r--nuttx/drivers/net/encx24j600.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/drivers/net/encx24j600.c b/nuttx/drivers/net/encx24j600.c
index a0d90761a..2665f9694 100644
--- a/nuttx/drivers/net/encx24j600.c
+++ b/nuttx/drivers/net/encx24j600.c
@@ -1179,7 +1179,7 @@ static int enc_txenqueue(FAR struct enc_driver_s *priv)
*
* Description:
* Enqueues uIP packets if available.
* This is a callback from uip_poll(). uip_poll() may be called:
*
* 1. When the preceding TX packet send is complete,
* 2. When the preceding TX packet send timedout and the interface is reset
@@ -1305,7 +1305,7 @@ static void enc_txif(FAR struct enc_driver_s *priv)
/* Poll for uip packets */
- uip_poll(&priv->dev, enc_uiptxpoll);
+ devif_poll(&priv->dev, enc_uiptxpoll);
}
else
{
@@ -2005,7 +2005,7 @@ static void enc_toworker(FAR void *arg)
/* Then poll uIP for new XMIT data */
- (void)uip_poll(&priv->dev, enc_uiptxpoll);
+ (void)devif_poll(&priv->dev, enc_uiptxpoll);
/* Release uIP */
@@ -2095,7 +2095,7 @@ static void enc_pollworker(FAR void *arg)
* in progress, we will missing TCP time state updates?
*/
- (void)uip_timer(&priv->dev, enc_uiptxpoll, ENC_POLLHSEC);
+ (void)devif_timer(&priv->dev, enc_uiptxpoll, ENC_POLLHSEC);
}
/* Release lock on the SPI bus and uIP */
@@ -2321,7 +2321,7 @@ static int enc_txavail(struct net_driver_s *dev)
{
/* The interface is up and TX is idle; poll uIP for new XMIT data */
- (void)uip_poll(&priv->dev, enc_uiptxpoll);
+ (void)devif_poll(&priv->dev, enc_uiptxpoll);
}
}
@@ -1179,7 +1179,7 @@ static int enc_txenqueue(FAR struct enc_driver_s *priv)
* Description:
* Enqueues uIP packets if available.
- * This is a callback from uip_poll(). uip_poll() may be called:
+ * This is a callback from devif_poll(). devif_poll() may be called:
*
* 1. When the preceding TX packet send is complete,